@@ -5,7 +5,7 @@
  *  David Corcoran <corcoran@linuxnet.com>
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: winscard.h,v 1.1.1.5 2006-08-11 18:49:10 rousseau Exp $
+ * $Id: winscard.h,v 1.7 2007-01-25 14:55:37 rousseau Exp $
  */
 
 /**
@@ -32,6 +32,8 @@ extern "C"
 
 	PCSC_API LONG SCardReleaseContext(SCARDCONTEXT hContext);
 
+	PCSC_API LONG SCardIsValidContext(SCARDCONTEXT hContext);
+
 	PCSC_API LONG SCardSetTimeout(SCARDCONTEXT hContext, DWORD dwTimeout);
 
 	PCSC_API LONG SCardConnect(SCARDCONTEXT hContext,
@@ -88,8 +90,6 @@ extern "C"
 	PCSC_API LONG SCardSetAttrib(SCARDHANDLE hCard, DWORD dwAttrId,
 		LPCBYTE pbAttr, DWORD cbAttrLen);
 
-	void SCardUnload(void);
-
 #ifdef __cplusplus
 }
 #endif
