@@ -6,14 +6,14 @@
  * Copyright (C) 1999-2005
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: debug.c,v 1.1.1.2 2006-08-11 18:49:09 rousseau Exp $
+ * $Id: debug.c,v 1.1.1.3 2007-01-25 14:51:06 rousseau Exp $
  */
 
 /**
  * @file
  * @brief This handles debugging for libpcsclite.
  */
- 
+
 #include "config.h"
 #include <stdarg.h>
 #include <stdlib.h>
@@ -29,6 +29,7 @@
 static char LogLevel = PCSC_LOG_ERROR;
 
 static signed char LogDoColor = 0;	/* no color by default */
+void log_init(void);
 
 void log_init(void)
 {
@@ -53,7 +54,7 @@ void log_init(void)
 		term = getenv("TERM");
 		if (term)
 		{
-			int i;
+			unsigned int i;
 
 			/* for each known color terminal */
 			for (i = 0; i < sizeof(terms) / sizeof(terms[0]); i++)
