@@ -6,14 +6,14 @@
  * Copyright (C) 1999-2005
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: debuglog.c 2050 2006-05-20 14:26:13Z rousseau $
+ * $Id: debuglog.c 2302 2007-01-06 17:57:58Z rousseau $
  */
 
 /**
  * @file
  * @brief This handles debugging for pcscd.
  */
- 
+
 #include "config.h"
 #ifdef HAVE_SYSLOG_H
 #include <syslog.h>
@@ -32,9 +32,9 @@
 #include "sys_generic.h"
 #include "strlcpycat.h"
 
-/** 
+/**
  * Max string size when dumping a 256 bytes longs APDU
- * Should be bigger than 256*3+30 
+ * Should be bigger than 256*3+30
  */
 #define DEBUG_BUF_SIZE 2048
 
@@ -176,7 +176,7 @@ void DebugLogSetLogType(const int dbgtype)
 		term = getenv("TERM");
 		if (term)
 		{
-			int i;
+			unsigned int i;
 
 			/* for each known color terminal */
 			for (i = 0; i < sizeof(terms) / sizeof(terms[0]); i++)
