@@ -4,7 +4,7 @@
  * Copyright (C) 1999
  *  David Corcoran <corcoran@linuxnet.com>
  *
- * $Id: dyn_win32.c,v 1.1.1.5 2006-04-22 18:58:40 rousseau Exp $
+ * $Id: dyn_win32.c,v 1.10 2007-01-25 14:55:37 rousseau Exp $
  */
 
 /**
@@ -57,13 +57,13 @@ int DYN_CloseLibrary(void **pvLHandle)
 	return SCARD_S_SUCCESS;
 }
 
-int DYN_GetAddress(void *pvLHandle, void **pvFHandle, char *pcFunction)
+int DYN_GetAddress(void *pvLHandle, void **pvFHandle, const char *pcFunction)
 {
 	int rv;
 	char *pcFunctionName;
 
 	/*
-	 * Zero out everything 
+	 * Zero out everything
 	 */
 	rv = 0;
 	pcFunctionName = NULL;
