@@ -10,14 +10,14 @@
  * - BSD-like, see the COPYING file
  * - GNU Lesser General Licence 2.1 or (at your option) any later version.
  *
- * $Id: error.c,v 1.1.1.2 2006-08-11 18:49:09 rousseau Exp $
+ * $Id: error.c,v 1.1.1.3 2007-01-25 14:51:06 rousseau Exp $
  */
 
 /**
  * @file
  * @brief This handles pcsc_stringify_error()
  */
- 
+
 #include <stdio.h>
 #include <sys/types.h>
 
@@ -165,7 +165,7 @@ PCSC_API char* pcsc_stringify_error(long pcscError)
 	};
 
 	/* add a null byte */
-	strError[sizeof(strError)] = '\0';
+	strError[sizeof(strError)-1] = '\0';
 
 	return strError;
 }
