@@ -6,7 +6,7 @@
  * Copyright (C) 2004
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: eventhandler.c 2151 2006-09-06 20:02:47Z rousseau $
+ * $Id: eventhandler.c 2377 2007-02-05 13:13:56Z rousseau $
  */
 
 /**
@@ -24,7 +24,7 @@
 #include <stdlib.h>
 
 #include "misc.h"
-#include "pcsclite.h"
+#include "pcscd.h"
 #include "ifdhandler.h"
 #include "debuglog.h"
 #include "thread_generic.h"
@@ -259,7 +259,7 @@ void EHStatusHandlerThread(PREADER_CONTEXT rContext)
 			dwStatus &= ~SCARD_NEGOTIABLE;
 			dwStatus &= ~SCARD_SPECIFIC;
 			dwStatus &= ~SCARD_UNKNOWN;
-			Log2(PCSC_LOG_ERROR, "Error powering up card: %d", rv);
+			Log3(PCSC_LOG_ERROR, "Error powering up card: %d 0x%04X", rv, rv);
 		}
 
 		dwCurrentState = SCARD_PRESENT;
