@@ -7,7 +7,7 @@
  *  Toni Andjelkovic <toni@soth.at>
  *  Damien Sauveron <damien.sauveron@labri.fr>
  *
- * $Id: hotplug_libusb.c,v 1.8 2007-01-25 14:55:37 rousseau Exp $
+ * $Id: hotplug_libusb.c,v 1.9 2007-02-13 20:38:52 rousseau Exp $
  */
 
 /**
@@ -30,7 +30,8 @@
 #include <usb.h>
 
 #include "misc.h"
-#include "pcsclite.h"
+#include "wintypes.h"
+#include "pcscd.h"
 #include "debuglog.h"
 #include "parser.h"
 #include "readerfactory.h"
@@ -392,7 +393,8 @@ void HPEstablishUSBNotifications(void)
 				Log2(PCSC_LOG_INFO,
 					"Driver %s does not support IFD_GENERATE_HOTPLUG",
 					driverTracker[i].bundleName);
-				do_polling = TRUE;
+				if (HPForceReaderPolling < 1)
+					HPForceReaderPolling = 1;
 				break;
 			}
 
