@@ -5,7 +5,7 @@
  *  David Corcoran <corcoran@linuxnet.com>
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: pcscdaemon.c 2335 2007-01-11 18:05:12Z rousseau $
+ * $Id: pcscdaemon.c 2377 2007-02-05 13:13:56Z rousseau $
  */
 
 /**
@@ -34,6 +34,7 @@
 
 #include "misc.h"
 #include "pcsclite.h"
+#include "pcscd.h"
 #include "debuglog.h"
 #include "winscard_msg.h"
 #include "winscard_svc.h"
@@ -211,6 +212,14 @@ void SVCServiceRunLoop(void)
 
 			break;
 
+		case 2:
+			/*
+			 * timeout in SHMProcessEventsServer(): do nothing
+			 * this is used to catch the Ctrl-C signal at some time when
+			 * nothing else happens
+			 */
+			break;
+
 		case -1:
 			Log1(PCSC_LOG_ERROR, "Error in SHMProcessEventsServer");
 			break;
