@@ -6,7 +6,7 @@
  * Copyright (C) 2004
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: prothandler.c 2151 2006-09-06 20:02:47Z rousseau $
+ * $Id: prothandler.c 2377 2007-02-05 13:13:56Z rousseau $
  */
 
 /**
@@ -18,7 +18,7 @@
 #include <string.h>
 
 #include "misc.h"
-#include "pcsclite.h"
+#include "pcscd.h"
 #include "ifdhandler.h"
 #include "debuglog.h"
 #include "readerfactory.h"
