@@ -6,7 +6,7 @@
  *  Damien Sauveron <damien.sauveron@labri.fr>
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: readerfactory.c 2330 2007-01-11 16:54:16Z rousseau $
+ * $Id: readerfactory.c 2377 2007-02-05 13:13:56Z rousseau $
  */
 
 /**
@@ -25,7 +25,7 @@
 #include <fcntl.h>
 
 #include "misc.h"
-#include "pcsclite.h"
+#include "pcscd.h"
 #include "ifdhandler.h"
 #include "debuglog.h"
 #include "thread_generic.h"
@@ -1114,7 +1114,10 @@ LONG RFInitializeReader(PREADER_CONTEXT rContext)
   /******************************************/
 	rv = RFLoadReader(rContext);
 	if (rv != SCARD_S_SUCCESS)
+	{
+		Log2(PCSC_LOG_ERROR, "RFLoadReader failed: %X", rv);
 		return rv;
+	}
 
   /*******************************************/
 	/*
@@ -1125,6 +1128,7 @@ LONG RFInitializeReader(PREADER_CONTEXT rContext)
 
 	if (rv != SCARD_S_SUCCESS)
 	{
+		Log2(PCSC_LOG_ERROR, "RFBindFunctions failed: %X", rv);
 		RFUnloadReader(rContext);
 		return rv;
 	}
