@@ -6,7 +6,7 @@
  * Copyright (C) 2004
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: readerfactory.h 2072 2006-06-06 09:31:07Z rousseau $
+ * $Id: readerfactory.h 2330 2007-01-11 16:54:16Z rousseau $
  */
 
 /**
@@ -17,6 +17,8 @@
 #ifndef __readerfactory_h__
 #define __readerfactory_h__
 
+#include <inttypes.h>
+
 #include "thread_generic.h"
 #include "ifdhandler.h"
 
@@ -92,7 +94,7 @@ extern "C"
 	typedef struct FctMap_V3 FCT_MAP_V3, *PFCT_MAP_V3;
 
 	/*
-	 * The following is not currently used but in place if needed 
+	 * The following is not currently used but in place if needed
 	 */
 
 	struct RdrCapabilities
@@ -145,7 +147,7 @@ extern "C"
 		char lpcDevice[MAX_DEVICENAME];	/* Device Name */
 		PCSCLITE_THREAD_T pthThread;	/* Event polling thread */
 		PCSCLITE_MUTEX_T mMutex;	/* Mutex for this connection */
-		RDR_CLIHANDLES psHandles[PCSCLITE_MAX_READER_CONTEXT_CHANNELS];	
+		RDR_CLIHANDLES psHandles[PCSCLITE_MAX_READER_CONTEXT_CHANNELS];
                                          /* Structure of connected handles */
 		union
 		{
@@ -161,7 +163,7 @@ extern "C"
 		DWORD dwBlockStatus;	/* Current blocking status */
 		DWORD dwLockId;			/* Lock Id */
 		DWORD dwIdentity;		/* Shared ID High Nibble */
-		DWORD dwContexts;		/* Number of open contexts */
+		int32_t dwContexts;		/* Number of open contexts */
 		PDWORD pdwFeeds;		/* Number of shared client to lib */
 		PDWORD pdwMutex;		/* Number of client to mutex */
 
@@ -208,10 +210,10 @@ extern "C"
 	LONG RFClearReaderEventState(PREADER_CONTEXT, SCARDHANDLE);
 	LONG RFCheckReaderStatus(PREADER_CONTEXT);
 	void RFCleanupReaders(int);
-	int RFStartSerialReaders(char *readerconf);
+	int RFStartSerialReaders(const char *readerconf);
 	void RFReCheckReaderConf(void);
-	void RFSuspendAllReaders(void); 
-	void RFAwakeAllReaders(void); 
+	void RFSuspendAllReaders(void);
+	void RFAwakeAllReaders(void);
 
 #ifdef __cplusplus
 }
