@@ -6,7 +6,7 @@
  * Copyright (C) 1999
  *  David Corcoran <corcoran@linuxnet.com>
  *
- * $Id: sys_unix.c 2264 2006-12-03 13:15:03Z rousseau $
+ * $Id: sys_unix.c 2353 2007-01-23 10:31:50Z rousseau $
  */
 
 /**
@@ -100,8 +100,8 @@ INTERNAL int SYS_USleep(int iTimeVal)
 {
 #ifdef HAVE_NANOSLEEP
 	struct timespec mrqtp;
-	mrqtp.tv_sec = 0;
-	mrqtp.tv_nsec = iTimeVal * 1000;
+	mrqtp.tv_sec = iTimeVal/1000000;
+	mrqtp.tv_nsec = (iTimeVal - (mrqtp.tv_sec * 1000000)) * 1000;
 
 	return nanosleep(&mrqtp, NULL);
 #else
