@@ -5,7 +5,7 @@
  *  David Corcoran <corcoran@linuxnet.com>
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: winscard.c 2274 2006-12-12 13:08:22Z rousseau $
+ * $Id: winscard.c 2385 2007-02-05 13:55:01Z rousseau $
  */
 
 /**
@@ -83,7 +83,7 @@
 #include <sys/time.h>
 #include <string.h>
 
-#include "pcsclite.h"
+#include "pcscd.h"
 #include "winscard.h"
 #include "ifdhandler.h"
 #include "debuglog.h"
@@ -94,6 +94,89 @@
 #include "sys_generic.h"
 #include "eventhandler.h"
 
+#undef DO_PROFILE
+#ifdef DO_PROFILE
+
+#ifndef FALSE
+#define FALSE 0
+#define TRUE 1
+#endif
+
+#define PROFILE_FILE "/tmp/pcscd_profile"
+#include <stdio.h>
+#include <sys/time.h>
+#include <errno.h>
+#include <unistd.h>
+
+struct timeval profile_time_start;
+FILE *fd;
+char profile_tty;
+
+#define PROFILE_START profile_start(__FUNCTION__);
+#define PROFILE_END profile_end(__FUNCTION__, __LINE__);
+
+static void profile_start(const char *f)
+{
+	static char initialized = FALSE;
+
+	if (!initialized)
+	{
+		initialized = TRUE;
+		fd = fopen(PROFILE_FILE, "a+");
+		if (NULL == fd)
+		{
+			fprintf(stderr, "\33[01;31mCan't open %s: %s\33[0m\n",
+				PROFILE_FILE, strerror(errno));
+			exit(-1);
+		}
+		fprintf(fd, "\nStart a new profile\n");
+		fflush(fd);
+
+		if (isatty(fileno(stderr)))
+			profile_tty = TRUE;
+		else
+			profile_tty = FALSE;
+	}
+
+	gettimeofday(&profile_time_start, NULL);
+} /* profile_start */
+
+/* r = a - b */
+static long int time_sub(struct timeval *a, struct timeval *b)
+{
+	struct timeval r;
+	r.tv_sec = a -> tv_sec - b -> tv_sec;
+	r.tv_usec = a -> tv_usec - b -> tv_usec;
+	if (r.tv_usec < 0)
+	{
+		r.tv_sec--;
+		r.tv_usec += 1000000;
+	}
+
+	return r.tv_sec * 1000000 + r.tv_usec;
+} /* time_sub */
+
+
+static void profile_end(const char *f, int line)
+{
+	struct timeval profile_time_end;
+	long d;
+
+	gettimeofday(&profile_time_end, NULL);
+	d = time_sub(&profile_time_end, &profile_time_start);
+
+	if (profile_tty)
+		fprintf(stderr, "\33[01;31mRESULT %s \33[35m%ld\33[0m (%d)\n", f, d,
+			line);
+	fprintf(fd, "%s %ld\n", f, d);
+	fflush(fd);
+} /* profile_end */
+
+#else
+#define PROFILE_START
+#define PROFILE_END
+#endif
+
 /** used for backward compatibility */
 #define SCARD_PROTOCOL_ANY_OLD	 0x1000
 
@@ -190,6 +273,8 @@ LONG SCardConnect(SCARDCONTEXT hContext, LPCSTR szReader,
 	PREADER_CONTEXT rContext = NULL;
 	DWORD dwStatus;
 
+	PROFILE_START
+
 	/*
 	 * Check for NULL parameters
 	 */
@@ -249,7 +334,7 @@ LONG SCardConnect(SCARDCONTEXT hContext, LPCSTR szReader,
 	{
 		Log1(PCSC_LOG_INFO, "Waiting for release of lock");
 		while (rContext->dwLockId != 0)
-			SYS_USleep(100000);
+			SYS_USleep(PCSCLITE_LOCK_POLL_RATE);
 		Log1(PCSC_LOG_INFO, "Lock released");
 
 		/* Allow the status thread to convey information */
@@ -271,8 +356,15 @@ LONG SCardConnect(SCARDCONTEXT hContext, LPCSTR szReader,
 			Log1(PCSC_LOG_ERROR, "Card Not Inserted");
 			return SCARD_E_NO_SMARTCARD;
 		}
+
+		if (dwStatus & SCARD_SWALLOWED)
+		{
+			Log1(PCSC_LOG_ERROR, "Card Not Powered");
+			return SCARD_W_UNPOWERED_CARD;
+		}
 	}
 
+
 	/*******************************************
 	 *
 	 * This section tries to decode the ATR
@@ -393,6 +485,9 @@ LONG SCardConnect(SCARDCONTEXT hContext, LPCSTR szReader,
 				rContext->dwContexts -= 1;
 
 		*phCard = 0;
+
+		PROFILE_END
+
 		return SCARD_F_INTERNAL_ERROR;
 	}
 
@@ -401,6 +496,8 @@ LONG SCardConnect(SCARDCONTEXT hContext, LPCSTR szReader,
 	 */
 	SYS_USleep(PCSCLITE_STATUS_POLL_RATE + 10);
 
+	PROFILE_END
+
 	return SCARD_S_SUCCESS;
 }
 
@@ -410,6 +507,7 @@ LONG SCardReconnect(SCARDHANDLE hCard, DWORD dwShareMode,
 {
 	LONG rv;
 	PREADER_CONTEXT rContext = NULL;
+	int do_sleep = 1;
 
 	Log1(PCSC_LOG_DEBUG, "Attempting reconnect to token.");
 
@@ -571,6 +669,7 @@ LONG SCardReconnect(SCARDHANDLE hCard, DWORD dwShareMode,
 				break;
 		}
 
+		do_sleep = 1;
 	}
 	else
 		if (dwInitialization == SCARD_LEAVE_CARD)
@@ -578,6 +677,7 @@ LONG SCardReconnect(SCARDHANDLE hCard, DWORD dwShareMode,
 			/*
 			 * Do nothing
 			 */
+			do_sleep = 0;
 		}
 
 	/*******************************************
@@ -690,7 +790,8 @@ LONG SCardReconnect(SCARDHANDLE hCard, DWORD dwShareMode,
 	/*
 	 * Allow the status thread to convey information
 	 */
-	SYS_USleep(PCSCLITE_STATUS_POLL_RATE + 10);
+	if (do_sleep)
+		SYS_USleep(PCSCLITE_STATUS_POLL_RATE + 10);
 
 	return SCARD_S_SUCCESS;
 }
@@ -724,7 +825,7 @@ LONG SCardDisconnect(SCARDHANDLE hCard, DWORD dwDisposition)
 	{
 		Log1(PCSC_LOG_INFO, "Waiting for release of lock");
 		while (rContext->dwLockId != 0)
-			SYS_USleep(100000);
+			SYS_USleep(PCSCLITE_LOCK_POLL_RATE);
 		Log1(PCSC_LOG_INFO, "Lock released");
 	}
 
@@ -798,6 +899,10 @@ LONG SCardDisconnect(SCARDHANDLE hCard, DWORD dwDisposition)
 		else
 			Log1(PCSC_LOG_ERROR, "Error resetting card.");
 
+		/*
+		 * Allow the status thread to convey information
+		 */
+		SYS_USleep(PCSCLITE_STATUS_POLL_RATE + 10);
 	}
 	else if (dwDisposition == SCARD_EJECT_CARD)
 	{
@@ -863,11 +968,6 @@ LONG SCardDisconnect(SCARDHANDLE hCard, DWORD dwDisposition)
 	if (rContext->dwContexts < 0)
 		rContext->dwContexts = 0;
 
-	/*
-	 * Allow the status thread to convey information
-	 */
-	SYS_USleep(PCSCLITE_STATUS_POLL_RATE + 10);
-
 	return SCARD_S_SUCCESS;
 }
 
@@ -906,7 +1006,12 @@ LONG SCardBeginTransaction(SCARDHANDLE hCard)
 
 	rv = RFLockSharing(hCard);
 
-	Log2(PCSC_LOG_DEBUG, "Status: %d.", rv);
+	/* if the transaction is not yet ready we sleep a bit so the client
+	 * do not retry immediately */
+	if (SCARD_E_SHARING_VIOLATION == rv)
+		SYS_USleep(PCSCLITE_LOCK_POLL_RATE);
+
+	Log2(PCSC_LOG_DEBUG, "Status: 0x%08X", rv);
 
 	return rv;
 }
@@ -1054,7 +1159,7 @@ LONG SCardEndTransaction(SCARDHANDLE hCard, DWORD dwDisposition)
 	 */
 	RFUnlockSharing(hCard);
 
-	Log2(PCSC_LOG_DEBUG, "Status: %d.", rv);
+	Log2(PCSC_LOG_DEBUG, "Status: 0x%08X", rv);
 
 	return rv;
 }
@@ -1090,7 +1195,7 @@ LONG SCardCancelTransaction(SCARDHANDLE hCard)
 
 	rv = RFUnlockSharing(hCard);
 
-	Log2(PCSC_LOG_DEBUG, "Status: %d.", rv);
+	Log2(PCSC_LOG_DEBUG, "Status: 0x%08X", rv);
 
 	return rv;
 }
