@@ -6,7 +6,7 @@
  *  Damien Sauveron <damien.sauveron@labri.fr>
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: winscard_clnt.c 2319 2007-01-09 15:27:56Z rousseau $
+ * $Id: winscard_clnt.c 2377 2007-02-05 13:13:56Z rousseau $
  */
 
 /**
@@ -27,7 +27,7 @@
 #include <errno.h>
 
 #include "misc.h"
-#include "pcsclite.h"
+#include "pcscd.h"
 #include "winscard.h"
 #include "debug.h"
 #include "thread_generic.h"
@@ -69,8 +69,11 @@ static void profile_start(const char *f)
 
 	if (!initialized)
 	{
+		char filename[80];
+
 		initialized = TRUE;
-		fd = fopen(PROFILE_FILE, "a+");
+		sprintf(filename, "%s-%d", PROFILE_FILE, getuid());
+		fd = fopen(filename, "a+");
 		if (NULL == fd)
 		{
 			fprintf(stderr, "\33[01;31mCan't open %s: %s\33[0m\n",
@@ -115,6 +118,7 @@ static void profile_end(const char *f)
 	if (profile_tty)
 		fprintf(stderr, "\33[01;31mRESULT %s \33[35m%ld\33[0m\n", f, d);
 	fprintf(fd, "%s %ld\n", f, d);
+	fflush(fd);
 } /* profile_end */
 
 #else
@@ -1062,30 +1066,6 @@ LONG SCardBeginTransaction(SCARDHANDLE hCard)
 
 	do
 	{
-		/*
-		 * Look to see if it is locked before polling the server for
-		 * admission to the readers resources
-		 */
-		if ((readerStates[i])->lockState != 0)
-		{
-			int randnum = 0;
-			int j;
-
-			for (j = 0; j < 100; j++)
-			{
-				/*
-				 * This helps prevent starvation
-				 */
-				randnum = SYS_RandomInt(1000, 10000);
-				SYS_USleep(randnum);
-
-				if ((readerStates[i])->lockState == 0)
-				{
-					break;
-				}
-			}
-		}
-
 		rv = WrapSHMWrite(SCARD_BEGIN_TRANSACTION, psContextMap[dwContextIndex].dwClientID,
 			sizeof(scBeginStruct),
 			PCSCLITE_CLIENT_ATTEMPTS, (void *) &scBeginStruct);
