@@ -6,7 +6,7 @@
  *  Damien Sauveron <damien.sauveron@labri.fr>
  *  Ludoic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: winscard_msg.c 2321 2007-01-09 15:30:45Z rousseau $
+ * $Id: winscard_msg.c 2377 2007-02-05 13:13:56Z rousseau $
  */
 
 /**
@@ -36,7 +36,7 @@
 #endif
 
 #include "misc.h"
-#include "pcsclite.h"
+#include "pcscd.h"
 #include "winscard.h"
 #include "debug.h"
 #include "winscard_msg.h"
