@@ -6,7 +6,7 @@
  *  Damien Sauveron <damien.sauveron@labri.fr>
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: winscard_msg.h 2060 2006-05-25 21:35:58Z rousseau $
+ * $Id: winscard_msg.h 2308 2007-01-06 20:26:57Z rousseau $
  */
 
 /**
@@ -21,7 +21,7 @@
 /** Major version of the current message protocol */
 #define PROTOCOL_VERSION_MAJOR 2
 /** Minor version of the current message protocol */
-#define PROTOCOL_VERSION_MINOR 1
+#define PROTOCOL_VERSION_MINOR 2
 
 #ifdef __cplusplus
 extern "C"
@@ -88,7 +88,8 @@ extern "C"
 		SCARD_CANCEL_TRANSACTION = 0x0E,
 		SCARD_GET_ATTRIB = 0x0F,
 		SCARD_SET_ATTRIB = 0x10,
-		SCARD_TRANSMIT_EXTENDED = 0x11
+		SCARD_TRANSMIT_EXTENDED = 0x11,
+		SCARD_CONTROL_EXTENDED = 0x12
 	};
 
 	/**
@@ -266,7 +267,7 @@ extern "C"
 		DWORD pcbRecvLength;
 		LONG rv;
 		size_t size;
-		BYTE data[0];
+		BYTE data[1];
 	};
 	typedef struct transmit_struct_extended transmit_struct_extended;
 
@@ -288,6 +289,24 @@ extern "C"
 	};
 	typedef struct control_struct control_struct;
 
+	/**
+	 * @brief contained in \c SCARD_CONTROL_EXTENDED Messages.
+	 *
+	 * These data are passed throw the field \c sharedSegmentMsg.data.
+	 */
+	struct control_struct_extended
+	{
+		SCARDHANDLE hCard;
+		DWORD dwControlCode;
+		DWORD cbSendLength;
+		DWORD cbRecvLength;
+		DWORD pdwBytesReturned;
+		LONG rv;
+		size_t size;
+		BYTE data[1];
+	};
+	typedef struct control_struct_extended control_struct_extended;
+
 	/**
 	 * @brief contained in \c SCARD_GET_ATTRIB and \c  Messages.
 	 *
@@ -304,7 +323,7 @@ extern "C"
 	typedef struct getset_struct getset_struct;
 
 	/*
-	 * Now some function definitions 
+	 * Now some function definitions
 	 */
 
 	int SHMClientRead(psharedSegmentMsg, DWORD, int);
@@ -319,7 +338,7 @@ extern "C"
 		int filedes, int blockAmount);
 	int WrapSHMWrite(unsigned int command, DWORD dwClientID, unsigned int size,
 		unsigned int blockAmount, void *data);
-	void SHMCleanupSharedSegment(int, char *);
+	void SHMCleanupSharedSegment(int, const char *);
 
 #ifdef __cplusplus
 }
