@@ -6,7 +6,7 @@
  *  Damien Sauveron <damien.sauveron@labri.fr>
  *  Ludoic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: winscard_msg_srv.c,v 1.6 2007-01-25 14:55:37 rousseau Exp $
+ * $Id: winscard_msg_srv.c,v 1.7 2007-02-13 20:38:52 rousseau Exp $
  */
 
 /**
@@ -36,7 +36,7 @@
 #endif
 
 #include "misc.h"
-#include "pcsclite.h"
+#include "pcscd.h"
 #include "winscard.h"
 #include "debuglog.h"
 #include "winscard_msg.h"
@@ -165,10 +165,19 @@ INTERNAL int SHMInitializeCommonSegment(void)
  * @retval -1 Can not set the connection to non-blocking mode.
  * @retval 2 Timeout.
  */
+#if defined(__NetBSD__) || defined(__FreeBSD__) || defined(__OpenBSD__)
+#define DO_TIMEOUT
+#endif
 INTERNAL int SHMProcessEventsServer(PDWORD pdwClientID, int blocktime)
 {
 	fd_set read_fd;
 	int selret;
+#ifdef DO_TIMEOUT
+	struct timeval tv;
+	 	
+	tv.tv_sec = 1;
+	tv.tv_usec = 0;
+#endif
 
 	FD_ZERO(&read_fd);
 
@@ -178,7 +187,13 @@ INTERNAL int SHMProcessEventsServer(PDWORD pdwClientID, int blocktime)
 	FD_SET(commonSocket, &read_fd);
 
 	selret = select(commonSocket + 1, &read_fd, (fd_set *) NULL,
-		(fd_set *) NULL, NULL);
+		(fd_set *) NULL,
+#ifdef DO_TIMEOUT
+		&tv
+#else
+		NULL
+#endif
+		);
 
 	if (selret < 0)
 	{
@@ -190,6 +205,10 @@ INTERNAL int SHMProcessEventsServer(PDWORD pdwClientID, int blocktime)
 		return -1;
 	}
 
+	if (selret == 0)
+		/* timeout. On *BSD only */
+		return 2;
+
 	/*
 	 * A common pipe packet has arrived - it could be a new application
 	 */
