@@ -6,7 +6,7 @@
  *  Damien Sauveron <damien.sauveron@labri.fr>
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: winscard_svc.c 2250 2006-11-30 22:26:35Z rousseau $
+ * $Id: winscard_svc.c 2377 2007-02-05 13:13:56Z rousseau $
  */
 
 /**
@@ -24,7 +24,7 @@
 #include <stdio.h>
 #include <string.h>
 
-#include "pcsclite.h"
+#include "pcscd.h"
 #include "winscard.h"
 #include "debuglog.h"
 #include "winscard_msg.h"
